# Version managed by git-versioner
version = "v3.4"
version_short = "v3.5"
git_hash = "ad0bcd6"
on_tag = "v3.4"
dirty = False
SUPPORT_PATCH = False
